==> opennms-detectorclient-rpc-19.0.0-20160820.122939-18-sources.jar: org/opennms/netmgt/provision/detector/client/rpc/DetectorResponseDTO.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2016 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2016 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.provision.detector.client.rpc;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import org.opennms.core.rpc.api.RpcResponse;
import org.opennms.netmgt.provision.DetectResults;

@XmlRootElement(name = "detector-response")
@XmlAccessorType(XmlAccessType.NONE)
public class DetectorResponseDTO implements DetectResults, RpcResponse {

    @XmlAttribute(name = "detected")
    private boolean detected;

    @XmlAttribute(name = "failure-message")
    private String failureMesage;

    @XmlElement(name = "attribute")
    private List<DetectorAttributeDTO> attributes = new ArrayList<>();

    public DetectorResponseDTO() {
        // Default constructor for JAXB
    }

    public DetectorResponseDTO(DetectResults results) {
        setDetected(results.isServiceDetected());
        if (results.getServiceAttributes() != null) {
            addAttributes(results.getServiceAttributes());
        }
    }

    public DetectorResponseDTO(Throwable t) {
        setDetected(false);
        setFailureMesage(t.getMessage());
    }

    public boolean isDetected() {
        return detected;
    }

    public void setDetected(boolean detected) {
        this.detected = detected;
    }

    public String getFailureMesage() {
        return failureMesage;
    }

    public void setFailureMesage(String failureMesage) {
        this.failureMesage = failureMesage;
    }

    public List<DetectorAttributeDTO> getAttributes() {
        return attributes;
    }

    public void addAttribute(String key, String value) {
        attributes.add(new DetectorAttributeDTO(key, value));
    }

    public void addAttributes(Map<String, String> attributes) {
        attributes.entrySet().stream()
            .forEach(e -> addAttribute(e.getKey(), e.getValue()));
    }

    public Map<String, String> getAttributesMap() {
        return attributes.stream().collect(Collectors.toMap(DetectorAttributeDTO::getKey,
                DetectorAttributeDTO::getValue));
    }

    @Override
    public boolean isServiceDetected() {
        return detected;
    }

    @Override
    public Map<String, String> getServiceAttributes() {
        return getAttributesMap();
    }

    @Override
    public int hashCode() {
        return Objects.hash(detected, failureMesage, attributes);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        DetectorResponseDTO other = (DetectorResponseDTO) obj;
        return Objects.equals(this.detected, other.detected) &&
                Objects.equals(this.failureMesage, other.failureMesage) &&
                Objects.equals(this.attributes, other.attributes);
    }

}

==> opennms-detectorclient-rpc-19.0.0-20161004.051002-77-sources.jar: org/opennms/netmgt/provision/detector/client/rpc/DetectorResponseDTO.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2016 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2016 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.provision.detector.client.rpc;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import org.opennms.core.rpc.api.RpcResponse;
import org.opennms.netmgt.provision.DetectResults;

@XmlRootElement(name = "detector-response")
@XmlAccessorType(XmlAccessType.NONE)
public class DetectorResponseDTO implements DetectResults, RpcResponse {

    @XmlAttribute(name = "detected")
    private boolean detected;

    @XmlAttribute(name = "failure-message")
    private String failureMessage;

    @XmlElement(name = "attribute")
    private List<DetectorAttributeDTO> attributes = new ArrayList<>();

    public DetectorResponseDTO() {
        // Default constructor for JAXB
    }

    public DetectorResponseDTO(DetectResults results) {
        setDetected(results.isServiceDetected());
        if (results.getServiceAttributes() != null) {
            addAttributes(results.getServiceAttributes());
        }
    }

    public DetectorResponseDTO(Throwable t) {
        setDetected(false);
        setFailureMessage(t.getMessage());
    }

    public boolean isDetected() {
        return detected;
    }

    public void setDetected(boolean detected) {
        this.detected = detected;
    }

    public String getFailureMessage() {
        return failureMessage;
    }

    public void setFailureMessage(String failureMesage) {
        this.failureMessage = failureMesage;
    }

    public boolean didFailWithError() {
        return failureMessage != null && !failureMessage.isEmpty();
    }

    public List<DetectorAttributeDTO> getAttributes() {
        return attributes;
    }

    public void addAttribute(String key, String value) {
        attributes.add(new DetectorAttributeDTO(key, value));
    }

    public void addAttributes(Map<String, String> attributes) {
        attributes.entrySet().stream()
            .forEach(e -> addAttribute(e.getKey(), e.getValue()));
    }

    public Map<String, String> getAttributesMap() {
        return attributes.stream().collect(Collectors.toMap(DetectorAttributeDTO::getKey,
                DetectorAttributeDTO::getValue));
    }

    @Override
    public boolean isServiceDetected() {
        return detected;
    }

    @Override
    public Map<String, String> getServiceAttributes() {
        return getAttributesMap();
    }

    @Override
    public int hashCode() {
        return Objects.hash(detected, failureMessage, attributes);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        DetectorResponseDTO other = (DetectorResponseDTO) obj;
        return Objects.equals(this.detected, other.detected) &&
                Objects.equals(this.failureMessage, other.failureMessage) &&
                Objects.equals(this.attributes, other.attributes);
    }

}
